@@ -8,4 +8,4 @@ class DestinationRule(NamespacedResource):
     Destination Rule object.
     """
 
-    api_version = NamespacedResource.ApiGroup.NETWORKING_ISTIO_IO
+    api_group = NamespacedResource.ApiGroup.NETWORKING_ISTIO_IO
